@@ -5,7 +5,7 @@ ruma_api! {
         description: "Does something.",
         method: POST, // An `http::Method` constant. No imports required.
         name: "some_endpoint",
-        path: "/_matrix/some/endpoint/:baz",
+        unstable_path: "/_matrix/some/endpoint/:baz",
         rate_limited: false,
         authentication: None,
     }
